# auxi-mpp

[![PyPI version](https://img.shields.io/pypi/v/auxi-mpp)](https://pypi.org/project/auxi-mpp/)
[![CI](https://gitlab.com/auxi-oss/auxi-mpp/badges/main/pipeline.svg)](https://gitlab.com/auxi-oss/auxi-mpp/-/blob/main/.gitlab-ci.yml?ref_type=heads)
[![License](https://img.shields.io/badge/License-MIT-blue)](https://opensource.org/license/MIT)

`auxi` provides tools to help users do calculations for metallurgical process engineering.
`auxi-mpp` provides tools for calculating material physical properties.

## Installation

The following command will install the latest version of `auxi-mpp` from the [Python Package Index (PyPI)](https://pypi.org/project/auxi-mpp/).
You will need a working installation of Python and `pip` to run this command.

```bash
pip install -U auxi-mpp
```

## Contributing

We welcome contributions!
Please refer to the [contributors guide](https://gitlab.com/auxi-oss/gitlab-profile/-/blob/main/CONTRIBUTING.md?ref_type=heads) for more information.
